/// <reference types="react" />
import * as React from 'react';
import { BaseFieldProps } from 'redux-form';
import { UserModel } from './models/UserModel';
import AceSession from './models/AceSession';
/**
 * Code editor inputs used on a [redux-form](https://redux-form.com/6.0.0-rc.1/docs/api/reduxform.md/).
 */
declare namespace CodeEditorInput {
    interface Props extends BaseFieldProps {
        /** Input's name used when submitting form. */
        name: string;
        /** Input's label. */
        label?: string | JSX.Element;
        /** If true don't allow user to edit content. */
        readonly?: boolean;
        /** Tooltip text displayed when hovering "?" icon. */
        help?: string;
        /** CheckboxInput group CSS class. */
        containerClass?: string;
        /** CSS class applied to every input from the list. */
        inputClass?: string;
        /** Editor language mode. Default value is <strong>javascript</strong>. */
        mode: string;
        /** Editor height. */
        height?: number | string;
        /** Editor ace session. More details on [AceSession](http://localhost:6060/#acesession) */
        initSession?: AceSession;
        /**
         * Force save with keyboard shortcuts <strong>Ctrl + s</strong> or <strong>Cmd + s</strong>.
         */
        saveEditorContent?: (session: AceSession) => void;
        /** Save ace session after each update. */
        saveSession?: (session: AceSession) => void;
        /** Editor visual settings. More details on [Settings](http://localhost:6060/#settings). */
        displaySettings?: Settings;
        /** If updated, force update of component. */
        resetTick?: number;
        /** User session informations used to get his editor preferences. More details on [UserModel](http://localhost:6060/#usermodel). */
        user?: UserModel;
        /** Hide props from documentation */
        /** @ignore */
        children?: React.ReactNode;
        /** @ignore */
        key?: React.ReactText;
        /** @ignore */
        ref?: React.Ref<any>;
        /** redux-form props */
        /** @ignore */
        component?: any;
        /** @ignore */
        format?: any;
        /** @ignore */
        normalize?: any;
        /** @ignore */
        props?: any;
        /** @ignore */
        parse?: any;
        /** @ignore */
        validate?: any;
        /** @ignore */
        warn?: any;
        /** @ignore */
        withRef?: any;
    }
    interface Settings {
        theme?: string;
        fontSize?: string;
        showInvisibles?: boolean;
        showGutter?: boolean;
        showIndent?: boolean;
        wrap?: boolean;
    }
    interface State {
    }
}
declare class CodeEditorInput extends React.Component<CodeEditorInput.Props, CodeEditorInput.State> {
    constructor(props: CodeEditorInput.Props);
    render(): JSX.Element;
}
export default CodeEditorInput;
