"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
// Modules
var React = require("react");
var redux_form_1 = require("redux-form");
var classNames = require("classnames");
var uuid = require("uuid");
// Models
var UserModel_1 = require("./models/UserModel");
// Components
var help_1 = require("@amalto/help");
var CodeEditorInput = /** @class */ (function (_super) {
    __extends(CodeEditorInput, _super);
    function CodeEditorInput(props) {
        var _this = _super.call(this, props) || this;
        _this.state = {};
        return _this;
    }
    CodeEditorInput.prototype.render = function () {
        var _a = this.props, format = _a.format, normalize = _a.normalize, parse = _a.parse, validate = _a.validate, warn = _a.warn;
        var baseFieldProps = {
            name: name,
            format: format,
            normalize: normalize,
            parse: parse,
            validate: validate,
            warn: warn
        };
        return React.createElement(redux_form_1.Field, __assign({}, baseFieldProps, this.props, { component: CodeEditor }));
    };
    return CodeEditorInput;
}(React.Component));
var CodeEditor = /** @class */ (function (_super) {
    __extends(CodeEditor, _super);
    function CodeEditor(props) {
        var _this = _super.call(this, props) || this;
        _this.aceSession = null;
        _this.setEditorOptions = function (editor) {
            var userJson = _this.props.user ? UserModel_1.getUserJson(_this.props.user) : {};
            var userSettings = userJson ? userJson.codeEditorSettings || {} : {};
            var displaySettings = _this.props.displaySettings || {};
            editor.setTheme(displaySettings.theme || userSettings.theme || 'ace/theme/tomorrow_night_eighties');
            editor.setFontSize(displaySettings.fontSize || userSettings.fontSize || '12px');
            var showInvisibles = false;
            if (displaySettings.showInvisibles !== undefined) {
                showInvisibles = displaySettings.showInvisibles;
            }
            else if (userSettings.showInvisibles !== undefined) {
                showInvisibles = userSettings.showInvisibles;
            }
            editor.setShowInvisibles(showInvisibles);
            var showGutter = true;
            if (displaySettings.showGutter !== undefined) {
                showGutter = displaySettings.showGutter;
            }
            else if (userSettings.showGutter !== undefined) {
                showGutter = userSettings.showGutter;
            }
            editor.renderer.setShowGutter(showGutter);
            var wrap = false;
            if (displaySettings.wrap !== undefined) {
                wrap = displaySettings.wrap;
            }
            else if (userSettings.wrap !== undefined) {
                wrap = userSettings.wrap;
            }
            editor.getSession().setUseWrapMode(wrap);
            var showIndent = false;
            if (displaySettings.showIndent !== undefined) {
                showIndent = displaySettings.showIndent;
            }
            else if (userSettings.showIndent !== undefined) {
                showIndent = userSettings.showIndent;
            }
            editor.setDisplayIndentGuides(showIndent);
            editor.clearSelection();
        };
        _this.getAceSession = function () {
            var session = _this.state.editorInstance.session;
            var filterHistory = function (deltas) { return deltas.filter(function (d) { return d.group !== "fold"; }); };
            return {
                selection: session.selection['toJSON'](),
                value: session.getValue(),
                history: {
                    undo: session['$undoManager'].$undoStack.map(filterHistory),
                    redo: session['$undoManager'].$redoStack.map(filterHistory)
                },
                scrollTop: session.getScrollTop(),
                scrollLeft: session.getScrollLeft(),
                options: session['getOptions']()
            };
        };
        _this.restoreSession = function (editor, session) {
            var copy = ace.createEditSession(session.value, undefined);
            copy['$undoManager'].$doc = copy; // workaround for a bug in ace
            copy['$undoManager'].$undoStack = session.history.undo;
            copy['$undoManager'].$redoStack = session.history.redo;
            copy.setOptions(session.options);
            copy.setScrollTop(session.scrollTop);
            copy.setScrollLeft(session.scrollLeft);
            editor.setSession(copy);
            _this.setEditorOptions(editor);
            editor.$blockScrolling = Infinity;
            if (session.cursorPosition) {
                editor.selection.moveCursorToPosition(session.cursorPosition);
            }
            editor.focus();
            editor.setShowPrintMargin(false);
        };
        _this.isSessionSavable = function (editor) {
            var annotations = editor.getSession().getAnnotations();
            var isSavable = true;
            if (annotations.length === 0) {
                isSavable = true;
            }
            else {
                annotations.forEach(function (a) {
                    isSavable = a.type === 'error' ? false : isSavable;
                });
            }
            return isSavable;
        };
        _this.editorOnChange = function (e) {
            var _a = _this.props, initSession = _a.initSession, input = _a.input;
            var editor = _this.state.editorInstance;
            if (initSession) {
                initSession.cursorPosition = e.end;
                initSession.value = editor.getValue();
            }
            input.onChange(editor.getValue(), undefined, undefined);
        };
        _this.state = {
            editorId: uuid.v4()
        };
        _this.editorCtn = undefined;
        return _this;
    }
    CodeEditor.prototype.render = function () {
        var _this = this;
        var _a = this.props, label = _a.label, readonly = _a.readonly, help = _a.help, containerClass = _a.containerClass, inputClass = _a.inputClass, height = _a.height, input = _a.input, meta = _a.meta;
        var editorId = this.state.editorId;
        return (React.createElement("div", { className: classNames('form-group', containerClass, {
                'invalid': meta.touched && !!meta.error
            }) },
            label ? React.createElement("label", null,
                label,
                help && React.createElement(help_1.default, { text: help })) : null,
            React.createElement("div", { id: editorId, className: classNames('form-control input-block', inputClass), ref: function (dom) { return _this.editorCtn = dom; }, style: { height: height || 300 } }),
            (meta.touched && !!meta.error) && React.createElement("p", { className: "validation-error-message" }, meta.error)));
    };
    CodeEditor.prototype.componentDidMount = function () {
        var _this = this;
        this.setState({
            editorInstance: ace.edit(this.state.editorId)
        }, function () {
            var _a = _this.props, mode = _a.mode, readonly = _a.readonly, initSession = _a.initSession, input = _a.input, displaySettings = _a.displaySettings;
            var editor = _this.state.editorInstance;
            editor.getSession().setUndoManager(new ace.UndoManager()); // Typings incomplete, needed to reset undo manager
            editor.$blockScrolling = Infinity;
            if (input.value) {
                editor.setValue(input.value);
            }
            if (initSession) {
                _this.restoreSession(editor, initSession);
            }
            editor.getSession().setMode(mode || 'ace/mode/javascript');
            editor.setShowPrintMargin(false);
            editor.setReadOnly(readonly);
            _this.setEditorOptions(editor);
            _this.props.saveSession && _this.props.saveSession($.extend({}, _this.getAceSession(), {
                savable: _this.isSessionSavable(editor)
            }));
            editor.commands.addCommand({
                name: 'save',
                bindKey: { win: 'Ctrl-S', mac: 'Command-S' },
                exec: function (currentEditor) {
                    _this.props.saveEditorContent && _this.props.saveEditorContent($.extend({}, initSession, {
                        savable: _this.isSessionSavable(currentEditor),
                        cursorPosition: currentEditor.getCursorPosition()
                    }));
                }
            });
            editor.on('change', _this.editorOnChange);
        });
    };
    CodeEditor.prototype.componentDidUpdate = function (prevProps, prevState) {
        var editorInstance = this.state.editorInstance;
        var _a = this.props, readonly = _a.readonly, displaySettings = _a.displaySettings;
        if (editorInstance) {
            if (prevProps.readonly !== readonly) {
                editorInstance.setReadOnly(readonly);
            }
            if (prevProps.displaySettings !== displaySettings) {
                this.setEditorOptions(editorInstance);
            }
            if (prevProps.resetTick !== this.props.resetTick) {
                editorInstance.setValue(this.props.input.value);
                editorInstance.clearSelection();
            }
        }
    };
    CodeEditor.prototype.componentWillUnmount = function () {
        var saveSession = this.props.saveSession;
        var editorInstance = this.state.editorInstance;
        if (saveSession && editorInstance) {
            saveSession(this.getAceSession());
        }
        if (editorInstance) {
            editorInstance.removeListener('change', this.editorOnChange);
            editorInstance.destroy();
        }
    };
    return CodeEditor;
}(React.Component));
exports.default = CodeEditorInput;
//# sourceMappingURL=index.js.map