"use strict";
/**
 *  Created by Christopher VUONG
 *  Extend from XmlEditor
 */
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
// Modules
var React = require("react");
var ace = require("brace");
/**
 * Ace editor mode
 */
require("brace/mode/csharp");
require("brace/mode/dockerfile");
require("brace/mode/groovy");
require("brace/mode/html");
require("brace/mode/java");
require("brace/mode/javascript");
require("brace/mode/json");
require("brace/mode/typescript");
require("brace/mode/tsx");
require("brace/mode/xml");
/**
 * Ace editor theme
 */
require("brace/theme/ambiance");
require("brace/theme/chaos");
require("brace/theme/chrome");
require("brace/theme/clouds");
require("brace/theme/clouds_midnight");
require("brace/theme/cobalt");
require("brace/theme/crimson_editor");
require("brace/theme/dawn");
require("brace/theme/dracula");
require("brace/theme/dreamweaver");
require("brace/theme/eclipse");
require("brace/theme/github");
require("brace/theme/gob");
require("brace/theme/gruvbox");
require("brace/theme/idle_fingers");
require("brace/theme/iplastic");
require("brace/theme/katzenmilch");
require("brace/theme/kr_theme");
require("brace/theme/kuroir");
require("brace/theme/merbivore");
require("brace/theme/merbivore_soft");
require("brace/theme/mono_industrial");
require("brace/theme/monokai");
require("brace/theme/pastel_on_dark");
require("brace/theme/solarized_dark");
require("brace/theme/solarized_light");
require("brace/theme/sqlserver");
require("brace/theme/terminal");
require("brace/theme/textmate");
require("brace/theme/tomorrow");
require("brace/theme/tomorrow_night");
require("brace/theme/tomorrow_night_blue");
require("brace/theme/tomorrow_night_bright");
require("brace/theme/tomorrow_night_eighties");
require("brace/theme/twilight");
require("brace/theme/vibrant_ink");
require("brace/theme/xcode");
var Range = ace.acequire('ace/range').Range;
/**
 * Editor used outside a form. Principally used to display readable only exemple,
 * but can also keep current editor state if needed.
 */
var CodeEditor = /** @class */ (function (_super) {
    __extends(CodeEditor, _super);
    function CodeEditor(props) {
        var _this = _super.call(this, props) || this;
        _this._markerId = null;
        // Should be NodeJS.Timer but actual version of node js only have the prototype that return number
        _this._clearTimeout = null;
        _this._canUpdate = false;
        _this._cursorLastPosition = { row: 0, column: 0 };
        _this.resizeEditor = function () {
            var h = Math.max(document.documentElement.clientHeight, window.innerHeight || 0);
            $(_this._editorPanel).height(_this.props.height || 300);
            _this._editor.resize(true);
        };
        //see http://stackoverflow.com/questions/28257566/ace-editor-save-send-session-on-server-via-post
        _this.getAceSession = function (editor) {
            return _this.extractAceSession(editor);
        };
        _this.extractAceSession = function (editor) {
            var session = editor.getSession();
            var filterHistory = function (deltas) { return deltas.filter(function (d) { return d.group !== "fold"; }); };
            return {
                cursorPosition: session.getSelection().getCursor(),
                selection: session.selection['toJSON'](),
                value: session.getValue(),
                history: {
                    undo: session['$undoManager'].$undoStack.map(filterHistory),
                    redo: session['$undoManager'].$redoStack.map(filterHistory)
                },
                scrollTop: session.getScrollTop(),
                scrollLeft: session.getScrollLeft(),
                options: session['getOptions'](),
                firstChangeTime: _this._firstChangeTime
            };
        };
        _this.setEditorOptions = function (editor, props) {
            var userJson = props.userJson || {};
            var userSettings = userJson ? userJson.codeEditorSettings || {} : {};
            var displaySettings = props.displaySettings || {};
            editor.setTheme(displaySettings.theme && "ace/theme/" + displaySettings.theme || userSettings.theme || 'ace/theme/tomorrow_night_eighties');
            editor.setFontSize(displaySettings.fontSize || userSettings.fontSize || '12px');
            var showInvisibles = false;
            if (displaySettings.showInvisibles !== undefined) {
                showInvisibles = displaySettings.showInvisibles;
            }
            else if (userSettings.showInvisibles !== undefined) {
                showInvisibles = userSettings.showInvisibles;
            }
            editor.setShowInvisibles(showInvisibles);
            var showGutter = true;
            if (displaySettings.showGutter !== undefined) {
                showGutter = displaySettings.showGutter;
            }
            else if (userSettings.showGutter !== undefined) {
                showGutter = userSettings.showGutter;
            }
            editor.renderer.setShowGutter(showGutter);
            var wrap = false;
            if (displaySettings.wrap !== undefined) {
                wrap = displaySettings.wrap;
            }
            else if (userSettings.wrap !== undefined) {
                wrap = userSettings.wrap;
            }
            editor.getSession().setUseWrapMode(wrap);
            var showIndent = false;
            if (displaySettings.showIndent !== undefined) {
                showIndent = displaySettings.showIndent;
            }
            else if (userSettings.showIndent !== undefined) {
                showIndent = userSettings.showIndent;
            }
            editor.setDisplayIndentGuides(showIndent);
            // Not save in user settings
            editor.setHighlightActiveLine(displaySettings.highlight || true);
            displaySettings.fontFamily && editor.setOption('fontFamily', displaySettings.fontFamily);
            if (displaySettings.marker) {
                var range = displaySettings.marker;
                // this._markerId = this._editor.getSession().addMarker( new Range( range.row, range.column, range.row, range.column + 1 ), 'ace_error-marker', 'fullLine', false )
            }
        };
        _this.isSessionSavable = function (editor) {
            var annotations = editor.getSession().getAnnotations();
            var isSavable = true;
            if (annotations.length === 0) {
                isSavable = true;
            }
            else {
                annotations.forEach(function (a) {
                    isSavable = a.type === 'error' ? false : isSavable;
                });
            }
            return isSavable;
        };
        _this.setKeyboardShortcuts = function (editor, props) {
            editor.commands.addCommand({
                name: 'save',
                bindKey: { win: 'Ctrl-S', mac: 'Command-S' },
                exec: function (currentEditor) {
                    props.saveContent && props.saveContent($.extend({}, _this.extractAceSession(currentEditor), {
                        savable: _this.isSessionSavable(currentEditor),
                        cursorPosition: currentEditor.getCursorPosition()
                    }));
                }
            });
        };
        _this._firstChangeTime = -1;
        return _this;
    }
    CodeEditor.prototype.render = function () {
        var _this = this;
        var height = this.props.height || 300;
        return (React.createElement("div", { style: { height: height, width: '100%', position: 'relative' }, id: this.props.docId, ref: function (dom) { return _this._editorPanel = dom; } }));
    };
    CodeEditor.prototype.componentWillMount = function () {
        var _this = this;
        window.addEventListener('resize', function () { return _this.resizeEditor(); });
        this._markerId && this._editor.getSession().removeMarker(this._markerId);
    };
    CodeEditor.prototype.componentDidMount = function () {
        var _this = this;
        this._editor = ace.edit(this.props.docId);
        this._editor.$blockScrolling = Infinity;
        this._editor.setShowPrintMargin(false);
        this.setEditorSession(this._editor, this.props);
        this.setEditorOptions(this._editor, this.props);
        this._editor.setReadOnly(this.props.readonly);
        this.setKeyboardShortcuts(this._editor, this.props);
        this.resizeEditor();
        !this.props.readonly && this.focus(this.props.aceSession);
        this._clearTimeout = setInterval(function () {
            if (_this._canUpdate) {
                _this.props.saveSession && _this.props.saveSession($.extend({}, _this.getAceSession(_this._editor), { cursorPosition: _this._cursorLastPosition }));
                _this._canUpdate = false;
            }
        }, 12000);
        // Needed to be able to access this from editor onblur event
        var self = this;
        this._editor.on('blur', function (e) {
            var session = self.getAceSession(self._editor);
            if (self._canUpdate) {
                self._cursorLastPosition = e.end;
                session.cursorPosition = self._cursorLastPosition;
                self.props.saveSession && self.props.saveSession(session);
            }
        });
    };
    CodeEditor.prototype.componentWillUnmount = function () {
        var _this = this;
        window.removeEventListener('resize', function () { return _this.resizeEditor(); });
        //save current session
        this.props.saveSession && this.props.saveSession($.extend({}, this.getAceSession(this._editor), { cursorPosition: this._cursorLastPosition }));
        clearInterval(this._clearTimeout);
        //destroy the editor
        this._editor && this._editor.destroy();
    };
    CodeEditor.prototype.shouldComponentUpdate = function (nextProps) {
        var _this = this;
        var newDoc = nextProps.docId !== this.props.docId;
        if (this.props.mode !== nextProps.mode && nextProps.mode) {
            this._editor.getSession().setMode(nextProps.mode && "ace/mode/" + nextProps.mode);
        }
        if (this.props.saveSession && newDoc) {
            //save previous ACE Session
            this.props.saveSession(this.getAceSession(this._editor));
        }
        var displaySettingsChanged = this.props.displaySettings !== nextProps.displaySettings;
        var doUpdate = (newDoc || nextProps.loadTime > this._firstChangeTime);
        this._editor.setReadOnly(nextProps.readonly);
        if (doUpdate) {
            $(this._editorPanel).height(this.props.height || 300);
            this._editor.resize(true);
            !nextProps.readonly && this.focus(nextProps.aceSession);
            this.setEditorSession(this._editor, nextProps);
        }
        doUpdate && this.setEditorSession(this._editor, nextProps);
        displaySettingsChanged && this._markerId && this._editor.getSession().removeMarker(this._markerId);
        displaySettingsChanged && this.setEditorOptions(this._editor, nextProps);
        if (nextProps.moveToEndOfFile) {
            this._editor.getSelection().moveCursorFileEnd();
            this._editor.scrollToLine(this._editor.getSession().getLength(), false, true, function () { return _this._editor.scrollPageDown(); });
        }
        if (this.props.forceSave !== nextProps.forceSave && nextProps.forceSave) {
            this.props.saveSession(this.getAceSession(this._editor));
        }
        return doUpdate;
    };
    CodeEditor.prototype.componentDidUpdate = function () {
        !this.props.readonly && this.focus(this.props.aceSession);
    };
    CodeEditor.prototype.focus = function (session) {
        session && this._editor.moveCursorToPosition(session.cursorPosition);
        this._editor.focus();
    };
    CodeEditor.prototype.setEditorSession = function (editor, props) {
        var _this = this;
        //set new session
        if (props.aceSession) {
            CodeEditor.restoreSession(editor, props.aceSession);
            !props.readonly && this.focus(props.aceSession);
        }
        else {
            //editor.setValue( props.value as string, -1 )
            var session = ace.createEditSession(props.value, undefined);
            editor.setSession(session);
            //make sure the store is updated with the new session
            props.saveSession && props.saveSession(this.getAceSession(editor));
        }
        editor.getSession().setMode(props.mode && "ace/mode/" + props.mode || 'ace/mode/javascript');
        editor.getSession().on('change', function (e) {
            if (_this._firstChangeTime <= props.loadTime) {
                _this._firstChangeTime = new Date().getTime();
            }
            _this._canUpdate = true;
            _this._cursorLastPosition = e.end;
            _this.props.editorOnChange && _this.props.editorOnChange(_this._editor.getValue());
        });
        this._firstChangeTime = props.loadTime;
    };
    CodeEditor.restoreSession = function (editor, data) {
        var session = ace.createEditSession(data.value, undefined);
        session['$undoManager'].$doc = session; // workaround for a bug in ace
        session['setOptions'](data.options);
        session['$undoManager'].$undoStack = data.history.undo;
        session['$undoManager'].$redoStack = data.history.redo;
        session.selection['fromJSON'](data.selection);
        session.setScrollTop(data.scrollTop);
        //Workaround: INCORRECT TYPINGS FOR ACE @types node_module (22 nov. 2016)
        session.setScrollLeft(data.scrollLeft);
        editor.setSession(session);
    };
    return CodeEditor;
}(React.Component));
exports.default = CodeEditor;
//# sourceMappingURL=index.js.map