/// <reference types="react" />
import * as React from 'react';
export declare const CRON_VALIDATION: {
    SECOND: RegExp;
    MINUTE: RegExp;
    HOUR: RegExp;
    DAY_OF_MONTH: RegExp;
    MONTH: RegExp;
    DAY_OF_WEEK: RegExp;
    YEAR: RegExp;
};
/**
 * Cron input scheduler used on a [redux-form](https://redux-form.com/6.0.0-rc.1/docs/api/reduxform.md/).
 */
declare module CronInput {
    interface Props extends React.Props<CronInput> {
        /** Input's name. */
        name: string;
        /** Date value part. More details on [CronValue](http://localhost:6060/#cronvalue). */
        value: CronValue;
        /** Cron value onchange event. */
        handleChange: (fieldValue: CronValue) => void;
        /** Input's label. */
        label?: string | JSX.Element;
        /** Set input to invalid state and display error message. */
        invalid?: boolean;
        /** Input's CSS class. */
        containerClass?: string;
        /** Check cron value on component mount. */
        forceValidation?: boolean;
        /** Locale used. */
        locale: string;
        /** Hide props from documentation */
        /** @ignore */
        children?: React.ReactNode;
        /** @ignore */
        key?: React.ReactText;
        /** @ignore */
        ref?: React.Ref<CronInput>;
    }
    interface State {
        wordings?: {
            [id: string]: string;
        };
        enabled?: boolean;
        second?: string;
        minute?: string;
        hour?: string;
        dayOfMonth?: string;
        month?: string;
        dayOfWeek?: string;
        year?: string;
    }
    interface CronValue {
        enabled?: boolean;
        second?: string;
        minute?: string;
        hour?: string;
        dayOfMonth?: string;
        month?: string;
        dayOfWeek?: string;
        year?: string;
    }
}
declare class CronInput extends React.Component<CronInput.Props, CronInput.State> {
    constructor(props: CronInput.Props);
    render(): JSX.Element;
    private handleFieldChange;
    private getCronValue;
}
export default CronInput;
