/// <reference types="react" />
import * as React from 'react';
import { CustomFormData } from './models/Workflow';
import { WebApi } from './models/WebApi';
import NotificationModel from './models/NotificationModel';
import { ReduxProps } from './models/ReduxProps';
import FileWrapper from './models/FileWrapper';
/**
 * Custom component display on a modal's panel body
 */
declare namespace CustomFormDialog {
    interface Props extends React.Props<CustomFormDialog> {
        /** Interface used to perform all the api call to the server. More details on [WebApi](http://localhost:6060/#webapi). */
        api: WebApi;
        /** Allow you to handle your navigation. */
        appHistory: History;
        /** Panel title. */
        title: string;
        /** Initial state of the form. More details on [CustomFormData](http://localhost:6060/#customformdata). */
        formData: CustomFormData;
        /** Refresh component data. */
        refreshData: () => void;
        /** Close form. */
        closeForm: () => void;
        /** Confirm form submission. */
        confirmAction: (params: {
            [fieldName: string]: string | boolean;
        }) => void;
        /** Temporary token used to upload a file. */
        fileUploadSessionToken?: string;
        /** Generating a temporary token associated to the file you want to upload. */
        newFileUploadSession?: () => void;
        /** Cancel upload. */
        cancelFileUploadSession?: () => void;
        /** File to be uploaded. More details on [FileWrapper](http://localhost:6060/#filewrapper). */
        filesQueue?: {
            [fileName: string]: FileWrapper;
        };
        /** Append file to queue. */
        addFiles?: (files: File[]) => void;
        /** Remove file from queue. */
        deleteFile?: (fileName: string) => void;
        /** Display the custom confirmation modal. */
        showDialog: (title: string, body: React.ReactElement<any> | string, confirmAction?: any, cancelAction?: any, confirmLevel?: string, itemsList?: string[]) => void;
        /** Hide the confirmation modal. */
        hideDialog: () => void;
        /** Display a custom notification. More details on [NotificationModel](http://localhost:6060/#notificationmodel). */
        displayNotification: (notificationOptions: NotificationModel) => void;
        /** Display an error notification for  */
        handleErrorDisplay: (error: any) => void;
        /** Locale use. */
        locale: string;
        /** Hide props from documentation */
        /** @ignore */
        children?: React.ReactNode;
        /** @ignore */
        key?: React.ReactText;
        /** @ignore */
        ref?: React.Ref<CustomFormDialog>;
    }
    interface State {
        customComponent?: any;
        display?: JSX.Element;
        preventRedraw?: boolean;
        wordings?: {
            [id: string]: string;
        };
    }
    interface CustomComponentProps extends ReduxProps {
        title: string;
        closeForm: () => void;
        submitForm: (payload: {
            [fieldName: string]: string | boolean;
        }) => void;
        initialValues?: any;
        data?: any;
        fileUploadSessionToken?: string;
        newFileUploadSession?: () => void;
        cancelFileUploadSession?: () => void;
        filesQueue?: {
            [fileName: string]: FileWrapper;
        };
        addFiles?: (files: File[]) => void;
        deleteFile?: (fileName: string) => void;
        api: WebApi;
        appHistory: History;
        refreshData: () => void;
        showDialog: (title: string, body: React.ReactElement<any> | string, confirmAction?: any, cancelAction?: any, confirmLevel?: string, itemsList?: string[]) => void;
        hideDialog: () => void;
        displayNotification: (notificationOptions: NotificationModel) => void;
        handleErrorDisplay: (error: any) => void;
    }
}
declare class CustomFormDialog extends React.Component<CustomFormDialog.Props, CustomFormDialog.State> {
    constructor(props: CustomFormDialog.Props);
    render(): JSX.Element;
    componentDidMount(): void;
    componentDidUpdate(prevProps: CustomFormDialog.Props, prevState: CustomFormDialog.State): void;
    private refreshData;
    private getFormDisplay;
    private submitForm;
}
export default CustomFormDialog;
