"use strict";
/**
 * Created by franckmontaigne on 02/06/16.
 */
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
// Modules
var React = require("react");
var classNames = require("classnames");
// Utils
var helpers_1 = require("@amalto/helpers");
// Wordings
var wordings_1 = require("@amalto/wordings");
// Components
var color_picker_1 = require("@amalto/color-picker");
var HeaderItem = /** @class */ (function (_super) {
    __extends(HeaderItem, _super);
    function HeaderItem(props) {
        var _this = _super.call(this, props) || this;
        _this.handleCardContextMenu = function (event) {
            event.preventDefault();
            _this.updateContextMenu(event.clientX, event.clientY);
        };
        _this.updateContextMenu = function (positionX, positionY) {
            var _a = _this.props, displayTemplate = _a.displayTemplate, columnHeader = _a.columnHeader, displayContextMenu = _a.displayContextMenu;
            var itemDisplaySettings = displayTemplate ? displayTemplate[columnHeader.id] : null;
            var contextMenuContent = (React.createElement("div", { className: "padded" },
                React.createElement("div", { className: "bottom-margin top-margin" },
                    React.createElement("label", null, _this.state.wordings['headeritem.font.color']),
                    React.createElement(color_picker_1.default, { color: itemDisplaySettings.color, handleColorChange: _this.handleColorChange })),
                React.createElement("div", null,
                    React.createElement("button", { type: "button", className: "btn btn-sm btn-info btn-trans btn-block margin-none", onClick: _this.closeContextMenu }, "OK"))));
            displayContextMenu(contextMenuContent, positionX, positionY);
        };
        _this.handleColorChange = function (color) {
            var wordings = _this.state.wordings;
            var _a = _this.props, columnHeader = _a.columnHeader, templateChangeHandler = _a.templateChangeHandler;
            if (helpers_1.isValidColorCode(color)) {
                var template = {};
                template[columnHeader.id] = {
                    color: color
                };
                templateChangeHandler(template);
                window.setTimeout(_this.updateContextMenu, 250);
            }
            else {
                _this.props.displayNotification({
                    title: wordings['error'],
                    message: wordings['notification.invalid.color'],
                    level: 'error'
                });
            }
        };
        _this.closeContextMenu = function (event) {
            _this.props.hideContextMenu();
        };
        _this.handleMenuEnter = function (event) {
            $(event.currentTarget).addClass('on-mouse-over');
        };
        _this.handleMenuLeave = function (event) {
            $(event.currentTarget).removeClass('on-mouse-over');
        };
        _this.handleOrderChange = function (event) {
            event.preventDefault();
            var columnId = event.currentTarget.getAttribute('data-column-id');
            var order = event.currentTarget.getAttribute('data-order');
            if (columnId && order) {
                _this.props.orderHandler(columnId, order);
            }
        };
        _this.hideColumn = function (event) {
            event.preventDefault();
            var columnId = event.currentTarget.getAttribute('data-column-id');
            if (columnId) {
                _this.props.displayHandler(columnId, false);
            }
        };
        _this.handleSortChange = function (event) {
            event.preventDefault();
            var columnId = event.currentTarget.getAttribute('data-column-id');
            var _a = _this.props, columnHeader = _a.columnHeader, sortColumn = _a.sortColumn, sortDirection = _a.sortDirection, sortHandler = _a.sortHandler;
            if (columnId !== undefined && columnId !== null) {
                var newSortDirection = columnHeader.id === sortColumn ? (sortDirection === 'ASC' ? 'DESC' : 'ASC') : sortDirection;
                sortHandler(columnId, newSortDirection);
            }
        };
        _this.handleWidthChange = function (event) {
            event.preventDefault();
            var columnId = event.currentTarget.getAttribute('data-column-id');
            var way = event.currentTarget.getAttribute('data-way');
            if (columnId && way) {
                _this.props.widthHandler(columnId, way);
            }
        };
        _this.handleTextAlignChange = function (event) {
            event.preventDefault();
            var columnId = event.currentTarget.getAttribute('data-column-id');
            var align = event.currentTarget.getAttribute('data-align');
            if (columnId && align) {
                _this.props.textAlignHandler(columnId, align);
            }
        };
        //only for initialisation purpose, no duplication of props
        _this.state = {
            wordings: helpers_1.compileWordings(wordings_1.MULTILANGUAGE_WORDINGS, props.locale)
        };
        return _this;
    }
    HeaderItem.prototype.render = function () {
        var _a = this.props, columnHeader = _a.columnHeader, sortColumn = _a.sortColumn, sortDirection = _a.sortDirection, displayTemplate = _a.displayTemplate, preventTemplating = _a.preventTemplating, sortHandler = _a.sortHandler;
        var sortIcon = columnHeader.id === sortColumn ? (React.createElement("span", { className: classNames('dark-color sort-control fas', {
                'fa-long-arrow-alt-up': sortDirection === "ASC",
                'fa-long-arrow-alt-down': sortDirection === "DESC"
            }) })) : null;
        var itemDisplaySettings = displayTemplate ? displayTemplate[columnHeader.id] : null;
        //FIXME
        /* hardcoded access to desktop display mode */
        var headerStyle = itemDisplaySettings ? {
            width: itemDisplaySettings.desktop.width,
            textAlign: itemDisplaySettings.desktop.textAlign
        } : {
            width: 150
        };
        var align = 'left';
        if (itemDisplaySettings) {
            align = itemDisplaySettings.desktop.textAlign;
        }
        var advancedControls = displayTemplate && !columnHeader.disableClick && !preventTemplating ? (React.createElement("div", { className: "hover-menu", onContextMenu: this.handleCardContextMenu },
            React.createElement("div", { className: "hover-menu-btn-container" },
                React.createElement("span", { className: "info-color fas fa-fw fa-chevron-left", "data-column-id": columnHeader.id, "data-order": "up", onClick: this.handleOrderChange }),
                React.createElement("span", { className: classNames('fas fa-fw fa-sort', {
                        'info-color': !!sortHandler,
                        'default-color': !sortHandler
                    }), "data-column-id": columnHeader.id, onClick: this.handleSortChange }),
                React.createElement("span", { className: "info-color fas fa-fw fa-chevron-right", "data-column-id": columnHeader.id, "data-order": "down", onClick: this.handleOrderChange })),
            React.createElement("div", { className: "hover-menu-btn-container" },
                React.createElement("span", { className: "info-color fas fa-fw fa-trash-alt", "data-column-id": columnHeader.id, onClick: this.hideColumn }),
                React.createElement("span", { className: "info-color fas fa-fw fa-minus", "data-column-id": columnHeader.id, "data-way": "down", onClick: this.handleWidthChange }),
                React.createElement("span", { className: "info-color fas fa-fw fa-plus", "data-column-id": columnHeader.id, "data-way": "up", onClick: this.handleWidthChange })),
            React.createElement("div", { className: "hover-menu-btn-container" },
                React.createElement("span", { className: classNames('fas fa-fw fa-align-left', {
                        'info-color': align !== 'left',
                        'black-color': align === 'left'
                    }), "data-column-id": columnHeader.id, "data-align": "left", onClick: this.handleTextAlignChange }),
                React.createElement("span", { className: classNames('fas fa-fw fa-align-center', {
                        'info-color': align !== 'center',
                        'black-color': align === 'center'
                    }), "data-column-id": columnHeader.id, "data-align": "center", onClick: this.handleTextAlignChange }),
                React.createElement("span", { className: classNames('fas fa-fw fa-align-right', {
                        'info-color': align !== 'right',
                        'black-color': align === 'right'
                    }), "data-column-id": columnHeader.id, "data-align": "right", onClick: this.handleTextAlignChange })))) : null;
        var additionalProps = this.props.displayTemplate ? {
            onMouseEnter: this.handleMenuEnter,
            onMouseLeave: this.handleMenuLeave
        } :
            (this.props.sortHandler ? {
                onClick: this.handleSortChange
            } : {});
        if (this.props.columnHeader.disableClick) {
            additionalProps = {};
        }
        return (React.createElement("div", __assign({ key: columnHeader.id, style: headerStyle, className: classNames('dg-inline-header-item', {
                'sorted-by': sortIcon ? true : false,
                'click-pointer': this.props.sortHandler && !this.props.columnHeader.disableClick
            }), "data-column-id": columnHeader.id }, additionalProps),
            React.createElement("div", { className: "overflow-wrapper" },
                sortIcon,
                React.createElement("span", null, columnHeader.label)),
            advancedControls));
    };
    return HeaderItem;
}(React.Component));
exports.default = HeaderItem;
//# sourceMappingURL=HeaderItem.js.map