"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
// Modules
var React = require("react");
var classNames = require("classnames");
// Utils
var helpers_1 = require("@amalto/helpers");
var SelectablesContainer = /** @class */ (function (_super) {
    __extends(SelectablesContainer, _super);
    function SelectablesContainer(props) {
        var _this = _super.call(this, props) || this;
        _this._container = null;
        _this.displayContextMenu = function (event) {
            event.preventDefault();
            if (_this.props.selectedItems.length > 0 && _this.props.contextMenuContent) {
                _this.props.displayContextMenu(_this.props.contextMenuContent, event.clientX, event.clientY);
            }
        };
        _this.handleItemSelection = function (event) {
            event.preventDefault();
            var _a = _this.props, selectedItems = _a.selectedItems, onSelect = _a.onSelect;
            var itemIndex = parseInt(event.currentTarget.getAttribute('data-item-index'), 10);
            var idx = selectedItems.indexOf(itemIndex);
            //cmd + click or ctrl + click cases
            if (event.metaKey || event.ctrlKey) {
                //let's just be sure the user hasn't got its entire butt on the keyboard :)
                if (!event.shiftKey) {
                    //simply toggle the item from the selectedItems array
                    if (idx === -1) {
                        //if not already in, we add it
                        onSelect(selectedItems.concat(itemIndex));
                    }
                    else {
                        //else we remove it from the array
                        //copy of the array
                        var updatedItems = selectedItems.slice();
                        //remove the found item on the copy
                        updatedItems.splice(idx, 1);
                        onSelect(updatedItems);
                    }
                }
            }
            else if (event.shiftKey) {
                //if we click on an already selected item, do nothing, else go in that if
                if (idx === -1) {
                    if (selectedItems.length >= 1) {
                        var selectedIdx = itemIndex;
                        //case only one item selected
                        var currentMin = selectedItems[0];
                        var currentMax = currentMin;
                        //case multiple items already selected => set proper min & max to build the largest interval
                        if (selectedItems.length > 1) {
                            currentMin = helpers_1.arrayMin(selectedItems);
                            currentMax = helpers_1.arrayMax(selectedItems);
                        }
                        var min = Math.min(selectedIdx, currentMin);
                        var max = Math.max(selectedIdx, currentMax);
                        //build the interval
                        var interval = [];
                        var i = min;
                        for (i; i <= max; i++) {
                            interval.push(i);
                        }
                        onSelect(interval);
                    }
                    else {
                        onSelect([itemIndex]);
                    }
                    window.getSelection().removeAllRanges();
                }
            }
            else {
                //simply replace the selectedItems array with a new one containing only the new selected item
                onSelect([itemIndex]);
            }
        };
        return _this;
    }
    SelectablesContainer.prototype.render = function () {
        var _this = this;
        var selectableProps = {};
        if (!this.props.disableItemSelection) {
            selectableProps.onClick = this.handleItemSelection;
        }
        var selectableItems = this.props.orderedItems.map(function (selectable, idx) {
            return (React.createElement("span", __assign({ key: selectable.key && selectable.key + "_selectable" || idx, className: classNames('selectable', {
                    'selected': _this.props.selectedItems.indexOf(idx) !== -1
                }), "data-item-index": idx }, selectableProps), selectable));
        });
        var additionalProps = {};
        if (!this.props.disableContextMenu) {
            additionalProps.onContextMenu = this.displayContextMenu;
        }
        return (React.createElement("div", __assign({ ref: function (dom) { return _this._container = dom; } }, additionalProps), selectableItems));
    };
    SelectablesContainer.prototype.componentDidMount = function () {
        if (this.props.selectedItems.length === 1) {
            var $selectedElement_1 = $(this._container).find('[data-item-index="' + this.props.selectedItems[0] + '"]');
            window.setTimeout(function () {
                $('html').animate({ scrollTop: $selectedElement_1.position().top }, 500);
            }, 500);
        }
    };
    return SelectablesContainer;
}(React.Component));
exports.default = SelectablesContainer;
//# sourceMappingURL=SelectablesContainer.js.map