/// <reference types="react" />
/**
 * Created by franckmontaigne on 13/06/16.
 */
import * as React from 'react';
import { MapStateToProps } from 'react-redux';
import NotificationModel from './models/NotificationModel';
import { ColumnHeader, DataGridTemplates } from './models/DataGrid';
import { UserModel } from './models/UserModel';
import { WebApi } from './models/WebApi';
import { ReduxProps } from './models/ReduxProps';
import { DataGridActions } from './models/DataGridActions';
/**
 * Customizable grid.
 */
export declare namespace DataGrid {
    interface Props extends React.Props<DataGrid>, ReduxProps {
        /** Interface used to perform all the api call to the server. More details on [WebApi](http://localhost:6060/#webapi). */
        api: WebApi;
        /** Display context menu. */
        displayContextMenu: (content: any, positionX?: number, positionY?: number) => void;
        /** Hide contet menu. More details on [Action](http://localhost:6060/#action). */
        hideContextMenu: () => void;
        /** Display notification component. More details on [NotificationModel](http://localhost:6060/#notificationmodel). */
        displayNotification: (notificationOptions?: NotificationModel) => void;
        /** Display an request error on a notification component. */
        handleErrorDisplay: (error: any) => void;
        /** Display a modal on top of the page. */
        showDialog: (title: string, body: React.ReactElement<any> | string, confirmAction?: any, cancelAction?: any, confirmLevel?: string, itemsList?: string[], modalReadyCallback?: () => void) => void;
        /** Hide the modal previously open by the showDialog method. */
        hideDialog: () => void;
        /** Actions to disptach in order for the datagrid to work. */
        dataGridActions: DataGridActions;
        /** Save all interaction with DataGrid. */
        saveDataGridTemplate: (user: UserModel) => void;
        /** Must be added to allow templating. */
        dataGridId?: string;
        /** ServiceId used if the datagrid isn't part of a service */
        forcedServiceId?: string;
        /** If you want to prevent templating but need to give the dataGridId props, set this value to false. */
        preventTemplating?: boolean;
        /** Column data array to be displayed. More details on [ColumnHeader](http://localhost:6060/#columnheader). */
        columnHeaders: ColumnHeader[];
        /** DataLine components array to be displayed. */
        dataLines: JSX.Element[];
        /** Set true to display a spinner if columnHeaders is being poll from request. */
        fetchingHeaders?: boolean;
        /** Set true to hide DataGrid body if dataLines is being poll from request. */
        fetchingItems?: boolean;
        /** Message displayed when no items is provided. */
        noItemsMsg?: string;
        /** Event triggered when clicking on an header item. */
        sortHandler?: (columnId: string, sortDirection: string) => void;
        /** Column being sorted. */
        sortColumn?: string;
        /** Sort direction. */
        sortDirection?: string;
        /** Give the selected items. */
        selectHandler?: (selectedItemsIdx: number[]) => void;
        /** Index of the selected items. */
        selectedItems?: number[];
        /** Displayed when right clicking on selected items. */
        selectionContextMenu?: JSX.Element;
        /** Force update grid id updated. */
        resetTick?: number;
        /** If true, column header will be visible on top if user scroll down. */
        stickyHeader?: boolean;
        /** DataGrid customization state. More details on [DataGridTemplates](http://localhost:6060/#datagridtemplates). */
        templates?: DataGridTemplates;
        /** If templates has changed. */
        templatesChanged?: boolean;
        /** Current instance selected. */
        selectedAppInstanceName?: string;
        /** Default service id. */
        defaultServiceId?: string;
        /** User information store inside browser local storage. */
        user?: UserModel;
        /** Locale use. */
        locale: string;
        /** Hide props from documentation */
        /** @ignore */
        children?: React.ReactNode;
        /** @ignore */
        key?: React.ReactText;
        /** @ignore */
        ref?: React.Ref<DataGrid>;
    }
    interface State {
        displayHiddenColumnsPanel?: boolean;
        templateDialogOpened?: boolean;
        wordings?: {
            [id: string]: string;
        };
    }
}
export declare class DataGrid extends React.Component<DataGrid.Props, DataGrid.State> {
    static select: MapStateToProps<any, DataGrid.Props>;
    constructor(props: DataGrid.Props);
    componentWillMount(): void;
    componentDidMount(): void;
    componentDidUpdate(prevProps: DataGrid.Props): void;
    render(): JSX.Element;
    private getTemplateInjectedDataLines;
    private getDisplayTemplate;
    private bootstrapTemplate;
    private changeColumnOrder;
    private changeColumnWidth;
    private changeColumnTextAlign;
    private changeColumnDisplay;
    private resetTemplate;
    private changeTemplate;
    private getHiddenColumnsPanel;
    private displayContextMenu;
    private hideContextMenu;
    private saveDataGridTemplate;
}
export { DataGridActions };
declare const _default: any;
export default _default;
