/// <reference types="react" />
/// <reference types="pikaday" />
import * as React from 'react';
import * as Pikaday from 'pikaday';
/**
 * Choose a date from a calendar.
 */
declare module DatePicker {
    interface DateInputEvent {
        target: {
            value: any;
            name: string;
        };
    }
    interface Props extends React.Props<DatePicker> {
        /** Input name in the DOM. */
        name: string;
        /** Default value of the date picker. You can put the current value in here, usually stored in the state of the parent component. */
        defaultValue: string;
        /**
         * Date change event. More details on [DateInputEvent](http://localhost:6060/#dateinputevent).
         */
        handleDateChangeEvent?: (event: DateInputEvent) => void;
        /** Callback function executed on user input. */
        handleDateChange?: (date: string) => void;
        /** All dates before this one will be disabled in the date picker. */
        minDate?: string;
        /** All dates after this one will be disabled in the date picker. */
        maxDate?: string;
        /**
         * Will show a mandatory asterisk on the input label. Will disable the "clear selected date" button.
         * Warning: a default value for the date will be required otherwise the input will not be displayed.
         */
        mandatory?: boolean;
        /** Input's label. */
        label?: string | JSX.Element;
        /** Tooltip help displayed when hovering the "?" icon next to label. */
        help?: string;
        /** CSS class names applied to the input <strong>div</strong> container. */
        containerClass?: string;
        /** Hide props from documentation */
        /** @ignore */
        children?: React.ReactNode;
        /** @ignore */
        key?: React.ReactText;
        /** @ignore */
        ref?: React.Ref<DatePicker>;
        /** redux-form props */
        /** @ignore */
        component?: any;
        /** @ignore */
        format?: any;
        /** @ignore */
        normalize?: any;
        /** @ignore */
        props?: any;
        /** @ignore */
        parse?: any;
        /** @ignore */
        validate?: any;
        /** @ignore */
        warn?: any;
        /** @ignore */
        withRef?: any;
    }
    interface State {
        datePickerInstance?: Pikaday;
    }
}
/**
 * Datepicker which display a calendar when being click on.
 * There is a few customizations like a minimum and a maximum date range
 * of date available.
 */
declare class DatePicker extends React.Component<DatePicker.Props, DatePicker.State> {
    private _nameInput;
    constructor(props: DatePicker.Props);
    render(): JSX.Element;
    componentDidMount(): void;
    componentDidUpdate(): void;
    componentWillUnmount(): void;
    private setUpDatePicker;
    private clearDate;
}
export default DatePicker;
