/// <reference types="react" />
import * as React from 'react';
import { ReduxProps } from './models/ReduxProps';
import { WebApi } from './models/WebApi';
import NotificationModel from './models/NotificationModel';
import { AppKey } from './models/AppKey';
import { RunningJob } from './models/JobControl';
/**
 * Display any component passed as props.
 */
declare namespace DynamicComponent {
    interface Props extends React.Props<DynamicComponent> {
        /** Interface used to perform all the api call to the server. More details on [WebApi](http://localhost:6060/#webapi). */
        api: WebApi;
        /** Allow you to handle your navigation. */
        appHistory: History;
        /** Component to be display by an eval. */
        componentScript: string;
        /** Component data to be passed has props. */
        componentData?: any;
        /** Refresh data to be passed to component. */
        refreshData?: () => void;
        /** Context data saved into store to be restored on serveur. */
        contextData?: any;
        /** Store component data inside the store as contextData. */
        storeContext?: (contextData: any) => void;
        /** Set dirty status of the component. */
        setStatus?: (hasUnsavedChanges: boolean) => void;
        /** Component height. */
        height?: number;
        /** Component fullscreen status. */
        fullscreen?: boolean;
        /** Manage component fullscreen status. */
        setFullscreen?: (fullscreen: boolean) => void;
        /** Reload tooltip if not displayed correctly. */
        reloadTooltips?: () => void;
        /** Show current job status. */
        showJobStatus?: (jobId: string | number, callbackOnComplete?: (job: RunningJob) => void) => void;
        /** If any application publisher profile is accessible to user. */
        canSelectAppKey?: boolean;
        /** Current application publisher profile object selected. More details on [AppKey](http://localhost:6060/#appkey). */
        selectedAppKey?: AppKey;
        /** Current application publisher profile name selected. */
        selectedAppKeyName?: string;
        /** Application publisher profile is installed. */
        hasAppKeyInstalled?: (appKeyName: string) => boolean;
        /** Display the custom confirmation modal. */
        showDialog: (title: string, body: React.ReactElement<any> | string, confirmAction?: any, cancelAction?: any, confirmLevel?: string, itemsList?: string[]) => void;
        /** Hide the confirmation modal. */
        hideDialog: () => void;
        /** Display a custom notification. More details on [NotificationModel](http://localhost:6060/#notificationmodel). */
        displayNotification: (notificationOptions: NotificationModel) => void;
        /** Display an error notification for  */
        handleErrorDisplay: (error: any) => void;
        /** Locale use. */
        locale: string;
        /** Hide props from documentation */
        /** @ignore */
        children?: React.ReactNode;
        /** @ignore */
        key?: React.ReactText;
        /** @ignore */
        ref?: React.Ref<DynamicComponent>;
    }
    interface State {
        dynamicComponent?: any;
        display?: JSX.Element;
        preventRedraw?: boolean;
        wordings?: {
            [id: string]: string;
        };
    }
    interface CustomProps extends ReduxProps {
        data?: any;
        api: WebApi;
        refreshData: () => void;
        contextData?: any;
        storeContext?: (contextData: any) => void;
        appHistory: History;
        showDialog: (title: string, body: React.ReactElement<any> | string, confirmAction?: any, cancelAction?: any, confirmLevel?: string, itemsList?: string[]) => void;
        hideDialog: () => void;
        displayNotification: (notificationOptions: NotificationModel) => void;
        handleErrorDisplay: (error: any) => void;
        setStatus?: (hasUnsavedChanges: boolean) => void;
        height?: number;
        fullscreen?: boolean;
        setFullscreen?: (fullscreen: boolean) => void;
        reloadTooltips?: () => void;
        showJobStatus?: (jobId: string | number, callbackOnComplete?: (job: RunningJob) => void) => void;
        canSelectAppKey?: boolean;
        selectedAppKey?: AppKey;
        selectedAppKeyName?: string;
        hasAppKeyInstalled?: (appKeyName: string) => boolean;
    }
}
declare class DynamicComponent extends React.Component<DynamicComponent.Props, DynamicComponent.State> {
    constructor(props: DynamicComponent.Props);
    render(): JSX.Element;
    componentDidMount(): void;
    componentDidUpdate(prevProps: DynamicComponent.Props, prevState: DynamicComponent.State): void;
    private refreshData;
    private getComponentDisplay;
}
export default DynamicComponent;
