/// <reference types="react" />
import * as React from 'react';
import FileWrapper from './models/FileWrapper';
/**
 * Component allowing you to import multiple files.
 */
declare module FileInput {
    interface Props extends React.ClassAttributes<FileInput> {
        /**
         * Uploaded files list.
         * See below for the required data model behind the FileWrapper interface.
         */
        filesQueue: {
            [fileName: string]: FileWrapper;
        };
        /**
         * Callback function executed when the user drops some files in the uploader.
         */
        addFilesToQueue: (files: File[]) => void;
        /**
         * Callback function executed when the user clicks on the "Delete" button of a specific uploaded file.
         */
        deleteUploadedFile: (fileName: string) => void;
        /**
         * Callback function executed when the user clicks on the "Cancel" button.
         */
        cancelSubmit: () => void;
        /** Allowed mime types. */
        mimeTypeAccepted?: string;
        /** Max size in bytes (by file). */
        maxBytesSize?: number;
        /** Locale to be used by component. */
        locale: string;
        /** Hide props from documentation */
        /** @ignore */
        children?: React.ReactNode;
        /** @ignore */
        key?: React.ReactText;
        /** @ignore */
        ref?: React.Ref<FileInput>;
    }
    interface State {
        wordings?: {
            [key: string]: string;
        };
        submitDisabled?: boolean;
        invalidFiles?: File[];
    }
}
/**
 * FileInput allow you to upload several files.
 * You can click or drag and drop inside the block to do so.
 */
declare class FileInput extends React.Component<FileInput.Props, FileInput.State> {
    constructor(props: FileInput.Props);
    render(): JSX.Element;
    private onDrop;
    private closeInvalidFilesAlert;
    private deleteUploadedFile;
}
export default FileInput;
