import { Endpoints } from './models/AppEndpointsModel';
import { OrgModel, TreeNodeModel } from './models/Organisation';
export declare const EMAIL_REGEX: RegExp;
export declare const COLOR_CODE_REGEX: RegExp;
export declare const SCOPE_KEYWORD_REGEX: RegExp;
export declare const MAP_PROPERTY_KEY_REGEX: RegExp;
export declare const XML_TAG_REGEX: RegExp;
export declare const HTTPS_URL_REGEX: RegExp;
export declare function getWordingsInUserLanguage(locale: string): {
    [key: string]: string;
};
export declare function compileWordings(wordings: {
    [key: string]: any;
}, locale: string): {
    [key: string]: string;
};
/** Return gravater linked to use email. */
export declare function getGravatarUrl(email: string): string;
export declare function isValidPassword(password: string): boolean;
export declare function isValidEmail(email: string): boolean;
export declare function isValidColorCode(color: string): boolean;
export declare function isNotEmpty(value: string): boolean;
export declare function isValidScopeKeyword(value: string): boolean;
export declare function isValidKeyChar(value: string): boolean;
export declare function isValidXMLTag(value: string): boolean;
export declare function isValidHttpsUrl(value: string): boolean;
export declare function escapeXml(xml: string): string;
export declare function utf8JSON_to_b64URI(json: any): string;
export declare function URIb64_to_utf8JSON(str: any): any;
export declare function arrayMin(arr: number[]): number;
export declare function arrayMax(arr: number[]): number;
export declare function formatFileSize(size: number): string;
/**
 * Returns a key-value object from a query string like ?test=value&other=something
 */
export declare function getQueryParams(searchString: string): any;
/**
 * Adds a query parameter to a URI (string)
 * returns an HTMLAnchorElement
 */
export declare function addQueryParam(uri: string, key: string, value: any): HTMLAnchorElement;
export declare function orderAsc(object: Object): Object;
export declare function orderDesc(object: Object): Object;
export declare function saveDataAsJSONFile(data: any, fileName: string): void;
export declare function downloadDataFile(base64DataString: string, contentType: string, fileName: string): void;
export declare function hasRequiredResource(appEndpoints: Endpoints, appInstanceName: string, featureId: string): boolean;
export declare function replaceTemplateViewName(templatedHtml: string, viewName: string): string;
export declare function replaceTemplateFlags(templatedHtml: string, locale: string): string;
export declare function getStyleDef(styleConf: string): {
    icon: string;
    btn: string;
    color: string;
};
export declare function getAcceptLanguageHeader(locale: string): string;
export declare function getI18nLabel(locale: string, labelMap: {
    [language: string]: string;
}, noRegion?: boolean, upper?: boolean): string;
export declare function getJSTreeData(orgTreeData: OrgModel, openedNodes?: string[]): TreeNodeModel;
export declare function loadTooltips(element: Element): void;
export declare function unloadTooltips(element: Element): void;
export declare function groupByProperty(list: any[], propertyName: string): {
    [propValue: string]: any[];
};
/**
 * Add an element if it isn't already in the array
 * @param array Array to process
 * @param value Value to add
 */
export declare function addValToArrayNoDup(array: string[], value: string): string[];
/**
 * Remove all element from array that match the value parameter
 * @param array Array to process
 * @param value Value to exclude
 */
export declare function removeValFromArrayNoDup(array: string[], value: string): string[];
/**
 * Get nested value from object and pointed by a doted path
 * @param obj Object to search in
 * @param keyPath Path to search to
 */
export declare function getNestedValue(obj: any, keyPath: string): any;
/**
 * Filter collection by given  properties and matching string
 * @param collection Array to filter
 * @param properties Properties keys to sort the array by
 * @param searchString If given, only return value that contain this value
 */
export declare function filterCollection(collection: any[], properties: string[], searchString: string): any[];
export declare function base64Decode(encodedData: string): string;
/**
 * Copy object data into another object
 * @param data Object to copy and extend
 * @param extensions Object to inject into data
 */
export declare function deepCopy(data: any, extensions?: any): any;
/**
 * @description Handle dupplicate name from array
 * @param { string } name Name to check
 * @param { string[] } container String to compared to
 */
export declare function handleDuplicateNameFromArray(name: string, container: string[]): string;
/**
 * Return string date from timestamp and locale.
 * @param timestamp timestamp in milliseconde
 * @param locale locale to be used
 * @param options options of toLocaleString method
 */
export declare function dateByLocalToString(locale: string, date: number, options?: Intl.DateTimeFormatOptions): string;
