/// <reference types="react" />
import * as React from 'react';
import { PermissionDef } from './models/Scopes';
import { WebStorage } from './models/WebStorage';
/**
 * Display or hide component depending of user access.
 */
declare module Restricted {
    interface Props extends React.Props<Restricted> {
        /** Storage which contain instance and user informations. */
        webStorage: WebStorage;
        /** Actions which allow you to display children. */
        authorizedActions?: string[];
        /** Actions you want to use. */
        requiredActions?: string[];
        /** Feature you want to access. */
        featureId?: string;
        /** Permissions needed to display children. More details on [PermissionDef](http://localhost:6060/#permissiondef). */
        permissions?: string[] | PermissionDef[];
        /** Permission need to be in * instance. */
        needsGlobalPermission?: boolean;
        /** Hide props from documentation */
        /** @ignore */
        children?: React.ReactNode;
        /** @ignore */
        key?: React.ReactText;
        /** @ignore */
        ref?: React.Ref<Restricted>;
    }
}
declare class Restricted extends React.Component<Restricted.Props, any> {
    constructor(props: Restricted.Props);
    render(): React.ReactElement<any>;
}
export default Restricted;
