/// <reference types="react" />
import * as React from 'react';
import { BaseFieldProps } from 'redux-form';
/**
 * Text input used on a [redux-form](https://redux-form.com/6.0.0-rc.1/docs/api/reduxform.md/).
 */
declare namespace TextInput {
    interface Props extends BaseFieldProps {
        /** Input's name used when submitting form. */
        name: string;
        /** Input's label. */
        label?: string | JSX.Element;
        /** Input's placeholder. */
        placeholder?: string;
        /** Disable input. */
        disabled?: boolean;
        /** Tooltip text displayed when hovering "?" icon. */
        help?: string;
        /** CheckboxInput group CSS class. */
        containerClass?: string;
        /** CSS class applied to every input from the list. */
        inputClass?: string;
        /** Input's type. */
        type?: string;
        /** Focus the input after being loaded. */
        autofocus?: boolean;
        /** Randomize input value as a uuid.v1() string. */
        randomGenerator?: boolean;
        /**
         * Remove the bottom margin which is the default height of the error message
         * displayed when input is invalid.
         */
        collapseErrorSpace?: boolean;
        /** Hide props from documentation */
        /** @ignore */
        children?: React.ReactNode;
        /** @ignore */
        key?: React.ReactText;
        /** @ignore */
        ref?: React.Ref<TextInput>;
    }
    interface State {
    }
}
declare class TextInput extends React.Component<TextInput.Props, TextInput.State> {
    constructor(props: TextInput.Props);
    private renderText;
    render(): JSX.Element;
    private generateClientSecret;
}
export default TextInput;
