/// <reference types="react" />
import * as React from 'react';
import { BaseFieldProps } from 'redux-form';
import TimePicker from '@amalto/time-picker';
/**
 * Time input used on a [redux-form](https://redux-form.com/6.0.0-rc.1/docs/api/reduxform.md/).
 */
declare namespace TimeInput {
    interface Props extends BaseFieldProps {
        /** Input name in the DOM. */
        name: string;
        /** Whether or not the input is disabled. */
        disabled?: boolean;
        /** Input label. */
        label?: string | JSX.Element;
        /** Tooltip help displayed when hovering the "?" icon next to label. */
        help?: string;
        /**
         * Determined the interval in minute between each option from the select input.
         * @default 30
         */
        minutesInterval?: number;
        /** Minimum hour that can be selected. */
        minHour?: number;
        /** Maximum hour that can be selected. */
        maxHour?: number;
        /** CSS class names applied to the input <strong>div</strong> container. */
        containerClass?: string;
        /** Will show a mandatory asterisk on the input label. */
        mandatory?: boolean;
        /** Hide props from documentation */
        /** @ignore */
        children?: React.ReactNode;
        /** @ignore */
        key?: React.ReactText;
        /** @ignore */
        ref?: React.Ref<TimePicker>;
        /** redux-form props */
        /** @ignore */
        component?: any;
        /** @ignore */
        format?: any;
        /** @ignore */
        normalize?: any;
        /** @ignore */
        props?: any;
        /** @ignore */
        parse?: any;
        /** @ignore */
        validate?: any;
        /** @ignore */
        warn?: any;
        /** @ignore */
        withRef?: any;
    }
    interface State {
        hoursOptions?: string[];
        minutesOptions?: string[];
    }
}
declare class TimeInput extends React.Component<TimeInput.Props, TimeInput.State> {
    constructor(props: TimeInput.Props);
    private renderTimeInput;
    render(): JSX.Element;
}
export default TimeInput;
