/// <reference types="react" />
import * as React from 'react';
/**
 * Timepicker with few customizations like a minimum and a maximum time range of time available.
 */
declare module TimePicker {
    interface Props extends React.Props<TimePicker> {
        /** Input name in the DOM. */
        name: string;
        /** Time value. */
        value: string;
        /** Callback function executed on user input. */
        handleFieldChange: (fieldValue: string, fieldName: string) => void;
        /** Whether or not the input is disabled. */
        disabled?: boolean;
        /** Input label. */
        label?: string | JSX.Element;
        /** Tooltip help displayed when hovering the "?" icon next to label. */
        help?: string;
        /**
         * Determined the interval in minute between each option from the select input.
         * @default 30
         */
        minutesInterval?: number;
        /** Minimum hour that can be selected. */
        minHour?: number;
        /** Maximum hour that can be selected. */
        maxHour?: number;
        /** CSS class names applied to the input <strong>div</strong> container. */
        containerClass?: string;
        /** Will show a mandatory asterisk on the input label. */
        mandatory?: boolean;
        /** Hide props from documentation */
        /** @ignore */
        children?: React.ReactNode;
        /** @ignore */
        key?: React.ReactText;
        /** @ignore */
        ref?: React.Ref<TimePicker>;
    }
    interface State {
        hoursOptions?: string[];
        minutesOptions?: string[];
    }
}
declare class TimePicker extends React.Component<TimePicker.Props, TimePicker.State> {
    constructor(props: TimePicker.Props);
    render(): JSX.Element;
    componentDidUpdate(prevProps: TimePicker.Props): void;
    private renderTimeInput;
    private handleHoursChange;
    private handleMinutesChange;
    private getHoursOptions;
    private getMinutesOptions;
    private pad;
    private getUpdatedTime;
}
export default TimePicker;
