/// <reference types="react" />
import * as React from 'react';
/**
 * Panel component with configuration buttons.
 */
declare module TogglePanel {
    interface Props extends React.Props<TogglePanel> {
        /** Header title. */
        panelTitle: string | JSX.Element;
        /** Panel state on firt render. */
        defaultOpened: boolean;
        /**
         * Totally hide the header.
         * Props panelTitle, togglable, showSpinner, leftCustomControls and rightCustomControls wont be used if true.
         */
        hideTitle?: boolean;
        /** Alow user to open and close panel. */
        togglable?: boolean;
        /** Panel toggling event. */
        toggleCallback?: (opened: boolean) => void;
        /** Show spinner on the left side of header title. */
        showSpinner?: boolean;
        /** Buttons on the right side of the header title. */
        leftCustomControls?: JSX.Element;
        /** Buttons on the right side of the header panel. */
        rightCustomControls?: JSX.Element;
        /** Cancel button on the panel footer. */
        cancelBtn?: {
            label: string;
            action: any;
            cssClass?: string;
        };
        /** Submit button on the panel footer. */
        submitBtn?: {
            label: string;
            action: any;
            cssClass?: string;
        };
        /** CSS style of the panel. */
        customStyle?: React.CSSProperties;
        /** Hide props from documentation */
        /** @ignore */
        children?: React.ReactNode;
        /** @ignore */
        key?: React.ReactText;
        /** @ignore */
        ref?: React.Ref<TogglePanel>;
    }
    interface State {
        opened?: boolean;
    }
}
declare class TogglePanel extends React.Component<TogglePanel.Props, TogglePanel.State> {
    constructor(props: TogglePanel.Props);
    render(): JSX.Element;
    componentWillReceiveProps(nextProps: TogglePanel.Props): void;
    private togglePanelContent;
}
export default TogglePanel;
