"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
// Modules
var React = require("react");
var ReactDOM = require("react-dom");
var classNames = require("classnames");
// Utils
var helpers_1 = require("@amalto/helpers");
// Wordings
var wordings_1 = require("@amalto/wordings");
// Components
var key_value_editor_1 = require("@amalto/key-value-editor");
var Tree = /** @class */ (function (_super) {
    __extends(Tree, _super);
    function Tree(props) {
        var _this = _super.call(this, props) || this;
        _this._tree = null;
        _this.downloadFile = function (event) {
            if (_this.state.selectedNode) {
                var keyValues = _this.state.selectedNode.data.propertiesMap;
                var key = event.currentTarget.getAttribute('data-key');
                helpers_1.downloadDataFile(keyValues[key].contentBytes, keyValues[key].contentType, key);
            }
        };
        _this.expandAll = function (event) {
            if (_this.state.treeInstance) {
                _this.state.treeInstance.open_all(_this.state.selectedNode, 100);
            }
            if (event) {
                $(event.currentTarget).blur();
            }
        };
        _this.collapseAll = function (event) {
            if (_this.state.treeInstance) {
                _this.state.treeInstance.close_all(_this.state.selectedNode, 100);
            }
            if (event) {
                $(event.currentTarget).blur();
            }
        };
        _this.openCreateForm = function () {
            _this.setState({
                formOpened: 'CREATE',
                editedNode: {
                    parentId: _this.state.selectedNode.id,
                    elementName: '',
                    description: ''
                }
            });
        };
        _this.createNode = function () {
            var editedNode = _this.state.editedNode;
            var errors = [];
            if (helpers_1.isNotEmpty(editedNode.elementName)) {
                if (_this.state.selectedNode.data.childNames.indexOf(editedNode.elementName) !== -1) {
                    errors.push(_this.state.wordings['tree.node.invalid.name']);
                }
            }
            else {
                errors.push(_this.state.wordings['tree.node.name']);
            }
            if (!helpers_1.isNotEmpty(editedNode.description)) {
                errors.push(_this.state.wordings['tree.node.description']);
            }
            for (var key in editedNode.propertiesMap) {
                if (!key) {
                    errors.push(_this.state.wordings['tree.node.invalid.key']);
                }
            }
            if (errors.length > 0) {
                _this.props.displayEmptyValsError(errors);
            }
            else {
                _this.props.createNode(editedNode.parentId, editedNode.elementName.trim(), editedNode.description, editedNode.propertiesMap);
                _this.clearForm();
            }
        };
        _this.openEditForm = function () {
            _this.setState({
                formOpened: 'EDIT',
                editedNode: {
                    id: _this.state.selectedNode.id,
                    parentId: _this.state.selectedNode.data.parentId,
                    elementName: _this.state.selectedNode.text,
                    description: _this.state.selectedNode.data && _this.state.selectedNode.data.description,
                    propertiesMap: _this.state.selectedNode.data && _this.state.selectedNode.data.propertiesMap
                }
            });
        };
        _this.editNode = function () {
            var editedNode = _this.state.editedNode;
            var errors = [];
            if (!helpers_1.isNotEmpty(editedNode.elementName)) {
                errors.push(_this.state.wordings['tree.node.name']);
            }
            if (!helpers_1.isNotEmpty(editedNode.description)) {
                errors.push(_this.state.wordings['tree.node.description']);
            }
            for (var key in editedNode.propertiesMap) {
                if (!key) {
                    errors.push(_this.state.wordings['tree.node.invalid.key']);
                }
            }
            if (errors.length > 0) {
                _this.props.displayEmptyValsError(errors);
            }
            else {
                _this.props.editNode(editedNode.id, editedNode.elementName.trim(), editedNode.description, editedNode.propertiesMap, editedNode.parentId);
                _this.clearForm();
            }
        };
        _this.deleteNode = function () {
            _this.props.deleteNode(_this.state.selectedNode.id, _this.state.selectedNode.text, _this.state.selectedNode.data.parentId);
            _this.clearForm();
        };
        _this.clearForm = function () {
            _this.state.treeInstance.deselect_node(_this.state.selectedNode);
            _this.setState({
                editedNode: null,
                formOpened: null,
                selectedNode: null
            });
        };
        _this.handleElementNameChange = function (event) {
            var editedNodeUpdate = JSON.parse(JSON.stringify(_this.state.editedNode));
            editedNodeUpdate.elementName = event.target.value;
            _this.setState({
                editedNode: editedNodeUpdate
            });
        };
        _this.handleDescriptionChange = function (event) {
            var editedNodeUpdate = JSON.parse(JSON.stringify(_this.state.editedNode));
            editedNodeUpdate.description = event.target.value;
            _this.setState({
                editedNode: editedNodeUpdate
            });
        };
        _this.handlePropertiesChange = function (keyValues) {
            var editedNodeUpdate = JSON.parse(JSON.stringify(_this.state.editedNode));
            editedNodeUpdate.propertiesMap = keyValues;
            _this.setState({
                editedNode: editedNodeUpdate
            });
        };
        _this.setUpTree = function (id, data) {
            var treeContainer = ReactDOM.findDOMNode(_this._tree);
            var tree = $.jstree.create(treeContainer, {
                core: {
                    data: data,
                    check_callback: function (operation, node, node_parent, node_position, more) {
                        return operation !== 'move_node';
                    },
                    multiple: false,
                    error: undefined
                },
                plugins: ['sort'],
                sort: function (a, b) {
                    return this.get_node(a).text.localeCompare(this.get_node(b).text) < 0 ? -1 : 1;
                }
            });
            tree.hide_dots();
            $(treeContainer).on('select_node.jstree', function (event, selected) {
                _this.setState({
                    selectedNode: _this.getDecodedNode(selected.node),
                    editedNode: null,
                    formOpened: null
                });
                if (_this.props.selectCallback) {
                    _this.props.selectCallback(selected.node);
                }
            });
            $(treeContainer).on('deselect_node.jstree', function (event, selected) {
                _this.setState({
                    selectedNode: null,
                    editedNode: null,
                    formOpened: null
                });
                if (_this.props.selectCallback) {
                    _this.props.selectCallback(null);
                }
            });
            if (_this.props.defaultSelectedNodeId) {
                setTimeout(function () {
                    tree.select_node(_this.props.defaultSelectedNodeId);
                }, 500);
            }
            return tree;
        };
        _this.getDecodedNode = function (node) {
            var convertedNode = JSON.parse(JSON.stringify(node));
            if (convertedNode.data && convertedNode.data.propertiesMap && !$.isEmptyObject(convertedNode.data.propertiesMap)) {
                var nodeKeyValues = JSON.parse(JSON.stringify(convertedNode.data.propertiesMap));
                for (var key in nodeKeyValues) {
                    if (nodeKeyValues[key].contentType === 'text/plain') {
                        nodeKeyValues[key].contentBytes = helpers_1.base64Decode(nodeKeyValues[key].contentBytes);
                    }
                }
                convertedNode.data.propertiesMap = nodeKeyValues;
            }
            return convertedNode;
        };
        _this.state = {
            treeInstance: null,
            selectedNode: null,
            formOpened: null,
            editedNode: null,
            maxTreeHeight: 0,
            wordings: helpers_1.compileWordings(wordings_1.MULTILANGUAGE_WORDINGS, props.locale)
        };
        return _this;
    }
    Tree.prototype.render = function () {
        var _this = this;
        var disabled = !this.state.selectedNode;
        var editButton = this.state.formOpened === 'EDIT' ? (React.createElement("button", { className: "btn btn-block btn-warning", onClick: this.editNode }, this.state.wordings['tree.button.update'])) : null;
        var createButton = this.state.formOpened === 'CREATE' ? (React.createElement("button", { className: "btn btn-block btn-success", onClick: this.createNode }, this.state.wordings['tree.button.validate'])) : null;
        var canModifyTree = this.props.createNode && this.props.editNode && this.props.deleteNode && this.props.displayEmptyValsError;
        var cannotModifyNodeName = (this.state.formOpened !== 'CREATE' && this.state.selectedNode
            && (this.state.selectedNode.data.parentId === '0' || this.state.selectedNode.data.parentId === null));
        // Disable name input if can't edit it here
        var nodeForm = this.state.formOpened && canModifyTree ? (React.createElement("div", { className: "toggle-form bottom-margin" },
            React.createElement("div", { className: "row" },
                React.createElement("div", { className: "form-group col-xs-12 col-sm-6 col-md-4 col-lg-3" },
                    React.createElement("label", null, this.state.wordings['tree.node.name']),
                    React.createElement("input", { type: "text", className: "form-control", value: this.state.editedNode.elementName, onChange: this.handleElementNameChange, disabled: cannotModifyNodeName })),
                React.createElement("div", { className: "form-group col-xs-12 col-sm-6 col-md-4 col-lg-3" },
                    React.createElement("label", null, this.state.wordings['tree.node.description']),
                    React.createElement("input", { type: "text", className: "form-control", value: this.state.editedNode.description, onChange: this.handleDescriptionChange })),
                React.createElement("div", { className: "form-group col-xs-12 col-sm-6 col-md-4 col-lg-6" },
                    React.createElement("label", null, this.state.wordings['tree.node.properties']),
                    React.createElement(key_value_editor_1.default, { handleChange: this.handlePropertiesChange, keyValues: this.state.editedNode.propertiesMap, locale: this.props.locale })),
                React.createElement("div", { className: "col-xs-12" },
                    React.createElement("div", { className: "row" },
                        React.createElement("div", { className: "col-xs-12 col-sm-6 col-md-4 col-lg-3" },
                            React.createElement("div", { className: "top-margin" },
                                editButton,
                                createButton))))))) : null;
        var editor = (React.createElement("div", null,
            React.createElement("div", { className: "row text-xs-center" },
                React.createElement("div", { className: "col-xs-12" },
                    React.createElement("button", { disabled: disabled, className: classNames('btn btn-trans right-margin bottom-margin', {
                            'btn-primary': !disabled,
                            'btn-default': disabled
                        }), onClick: this.expandAll },
                        React.createElement("span", null, this.state.wordings['tree.expand.all.btn'])),
                    React.createElement("button", { disabled: disabled, className: classNames('btn btn-trans right-margin bottom-margin', {
                            'btn-primary': !disabled,
                            'btn-default': disabled
                        }), onClick: this.collapseAll },
                        React.createElement("span", null, this.state.wordings['tree.collapse.all.btn'])),
                    canModifyTree ? (React.createElement("span", null,
                        React.createElement("button", { disabled: disabled, className: classNames('btn btn-trans right-margin bottom-margin', {
                                'btn-success': !disabled,
                                'btn-default': disabled
                            }), onClick: this.openCreateForm }, this.state.wordings['tree.button.create']),
                        React.createElement("button", { disabled: disabled, className: classNames('btn btn-trans right-margin bottom-margin', {
                                'btn-warning': !disabled,
                                'btn-default': disabled
                            }), onClick: this.openEditForm }, this.state.wordings['tree.button.edit']),
                        React.createElement("button", { disabled: disabled, className: classNames('btn btn-trans right-margin bottom-margin', {
                                'btn-danger': !disabled,
                                'btn-default': disabled
                            }), onClick: this.deleteNode }, this.state.wordings['tree.button.delete']),
                        React.createElement("button", { disabled: disabled, className: classNames('btn btn-trans btn-default right-margin bottom-margin', {
                                'hidden': !this.state.formOpened
                            }), onClick: this.clearForm }, this.state.wordings['tree.button.cancel']))) : null)),
            nodeForm));
        var node = this.state.selectedNode;
        var selectedNodeProperties = node && node.data && node.data.propertiesMap && !$.isEmptyObject(node.data.propertiesMap) ?
            Object.keys(node.data.propertiesMap).map(function (key) {
                var nodeData = node.data;
                var dataDisplay = nodeData.propertiesMap[key].contentType === 'text/plain' ? (React.createElement("span", { className: "inline-middle" }, nodeData.propertiesMap[key].contentBytes)) : (React.createElement("button", { className: "inline-middle btn btn-xs btn-trans btn-info", "data-key": key, onClick: _this.downloadFile },
                    React.createElement("span", { className: "fas fa-download" })));
                return (React.createElement("li", { key: key },
                    React.createElement("em", { className: "right-spaced inline-middle" }, key),
                    React.createElement("span", { className: "fas fa-long-arrow-alt-right right-spaced inline-middle" }),
                    dataDisplay));
            }) : null;
        var selectedDetails = node ? (React.createElement("div", { className: "top-margin toggle-form" },
            React.createElement("div", { className: "row" },
                React.createElement("div", { className: "col-xs-12" },
                    React.createElement("h4", { className: "upper bottom-spaced" }, this.state.wordings['tree.selected.node.details'])),
                React.createElement("div", { className: "col-xs-12 col-sm-6 col-md-4 col-lg-3" },
                    React.createElement("div", { className: "text-small font-color-lighter" }, this.state.wordings['tree.node.name']),
                    React.createElement("div", null, node.text)),
                React.createElement("div", { className: "col-xs-12 col-sm-6 col-md-4 col-lg-3" },
                    React.createElement("div", { className: "text-small font-color-lighter" }, this.state.wordings['tree.node.id']),
                    React.createElement("div", { className: "word-wrap" },
                        React.createElement("em", null, node.id))),
                React.createElement("div", { className: "col-xs-12 col-sm-6 col-md-4 col-lg-3" },
                    React.createElement("div", { className: "text-small font-color-lighter" }, this.state.wordings['tree.node.description']),
                    React.createElement("div", null, node.data.description)),
                React.createElement("div", { className: "col-xs-12 col-sm-6 col-md-4 col-lg-3" },
                    React.createElement("div", { className: "text-small font-color-lighter" }, this.state.wordings['tree.node.properties']),
                    selectedNodeProperties ? React.createElement("ul", { className: "basic-list margin-none" }, selectedNodeProperties) : React.createElement("span", null, "-"))))) : null;
        return (React.createElement("div", { id: this.props.id, className: "text-medium" },
            React.createElement("div", { className: "tree-controls-container" }, editor),
            React.createElement("div", { style: { maxHeight: this.state.maxTreeHeight || 'none', overflow: 'auto' } },
                React.createElement("div", { ref: function (dom) { return _this._tree = dom; }, id: this.props.id })),
            React.createElement("div", { className: "tree-details-container" },
                selectedDetails,
                this.props.children)));
    };
    Tree.prototype.componentDidMount = function () {
        var tree = this.setUpTree(this.props.id, this.props.data);
        this.setState({
            treeInstance: tree
        });
    };
    Tree.prototype.componentDidUpdate = function (prevProps, prevState) {
        if (prevState.selectedNode !== this.state.selectedNode || prevProps.children !== this.props.children) {
            // window height - tree action buttons container height - details container - header, paddings and nav tabs
            var maxTreeHeight = window.innerHeight - $('#' + this.props.id + ' .tree-controls-container').outerHeight() - $('#' + this.props.id + ' .tree-details-container .toggle-form').outerHeight() - 212;
            //if we have a user assign form, we reduce a bit more the tree height to fully display selected node details and user assign form (this.props.children)
            if (this.props.children) {
                maxTreeHeight -= 62;
            }
            this.setState({
                maxTreeHeight: maxTreeHeight
            });
        }
    };
    Tree.prototype.componentWillReceiveProps = function (nextProps) {
        if (this.props.data !== nextProps.data) {
            if (this.state.treeInstance) {
                this.state.treeInstance.destroy(false);
                this.setState({
                    treeInstance: this.setUpTree(nextProps.id, nextProps.data),
                    selectedNode: null,
                    editedNode: null,
                    formOpened: null
                });
            }
        }
    };
    Tree.prototype.componentWillUnmount = function () {
        if (this.state.treeInstance) {
            this.state.treeInstance.destroy();
        }
        var treeContainer = ReactDOM.findDOMNode(this._tree);
        $(treeContainer).off();
    };
    return Tree;
}(React.Component));
exports.default = Tree;
//# sourceMappingURL=index.js.map