/// <reference types="react" />
import * as React from 'react';
/**
 * Simple select or input with a validation by regular expression or method check used on a [redux-form](https://redux-form.com/6.0.0-rc.1/docs/api/reduxform.md/).
 */
declare module ValidatedInput {
    interface Props extends React.Props<ValidatedInput> {
        /** Input name in the DOM. */
        name: string;
        /** Input value. */
        value: string;
        /** Callback function executed on user input. */
        handleFieldChange: (fieldValue: string, fieldName: string, isInvalid: boolean) => void;
        /** If given, ValidatedInput will be a select balise instead of an input balise. */
        choices?: {
            value: string;
            label?: string;
        }[];
        /**
         * Regular expression to validate the user input against.
         * If the user input does not match the regex, it will take an invalid appearance.
         */
        regex?: RegExp;
        /**
         * A callback function to validate the user input against.
         * If the user input (fieldValue) is not valid, this function should return false.
         * It can be used in place or in combination with the regex validation.
         */
        validate?: (fieldValue: string) => boolean;
        /** Custom error message displayed when the user input is invalid. */
        errorMessage?: string;
        /** Whether or not the input is disabled. */
        disabled?: boolean;
        /** If true, value must be defined and can't be cleared. */
        mandatory?: boolean;
        /** Input label. */
        label?: string | JSX.Element;
        /** Forces the input to be validated (regex/mandatory validation) on first load - before the user starts to type anything. */
        validateOnLoad?: boolean;
        /** Whether or not the form has been submitted. Will force an input validation if it goes from false to true. */
        formSubmitted?: boolean;
        /** Placeholder HTML attribute. */
        placeholder?: string;
        /** Autocomplete HTML attribute. */
        autoComplete?: string;
        /** Tooltip help displayed when hovering the "?" icon next to label. */
        help?: string;
        /** Input and label parent class. */
        containerClass?: string;
        /** Input class. */
        inputClass?: string;
        /** Hide props from documentation */
        /** @ignore */
        children?: React.ReactNode;
        /** @ignore */
        key?: React.ReactText;
        /** @ignore */
        ref?: React.Ref<ValidatedInput>;
    }
    interface State {
        invalidInput?: boolean;
    }
}
declare class ValidatedInput extends React.Component<ValidatedInput.Props, ValidatedInput.State> {
    constructor(props: ValidatedInput.Props);
    render(): JSX.Element;
    componentDidMount(): void;
    componentWillReceiveProps(nextProps: ValidatedInput.Props): void;
    private handleChange;
    private validateField;
}
export default ValidatedInput;
